==> vitamui-package-8.1.2-MVN_REPO.tar.gz: fr/gouv/vitamui/iam/security/filter/RequestHeadersAuthenticationFilter.java <==
/**
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2019-2020)
 * and the signatories of the "VITAM - Accord du Contributeur" agreement.
 *
 * contact@programmevitam.fr
 *
 * This software is a computer program whose purpose is to implement
 * implement a digital archiving front-office system for the secure and
 * efficient high volumetry VITAM solution.
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
package fr.gouv.vitamui.iam.security.filter;

import fr.gouv.vitamui.commons.rest.client.HttpContext;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.web.authentication.preauth.x509.X509AuthenticationFilter;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Objects;

/**
 * The authentication filter based on the request headers.
 */
public class RequestHeadersAuthenticationFilter extends X509AuthenticationFilter {

    private final List<X509CertificateExtractor> x509CertificateExtractors;

    private final List<TokenExtractor> tokenExtractors;

    /**
     *
     * @param authenticationManager
     * @param x509CertificateExtractors
     * @param tokenExtractors
     */
    public RequestHeadersAuthenticationFilter(
        final AuthenticationManager authenticationManager,
        final List<X509CertificateExtractor> x509CertificateExtractors,
        List<TokenExtractor> tokenExtractors
    ) {
        super();
        setAuthenticationManager(authenticationManager);
        this.x509CertificateExtractors = x509CertificateExtractors;
        this.tokenExtractors = tokenExtractors;
    }

    /**
     * Return as principal the External Http Context that is built from the request
     */
    @Override
    protected Object getPreAuthenticatedPrincipal(final HttpServletRequest request) {
        logger.debug("request: " + request.getRequestURI() + " - " + request.getQueryString());
        return HttpContext.buildFromExternalRequest(request, extractToken(request));
    }

    private String extractToken(HttpServletRequest request) {
        return tokenExtractors
            .stream()
            .map(tokenExtractor -> tokenExtractor.extract(request))
            .filter(Objects::nonNull)
            .findFirst()
            .orElse(null);
    }

    /**
     * Return as credentials the certificate extracted from the request
     */
    @Override
    protected Object getPreAuthenticatedCredentials(final HttpServletRequest request) {
        // This is a temporary patch to allow both mTLS authentication behind gateway or full mTLS during migration
        return x509CertificateExtractors
            .stream()
            .map(x509CertificateExtractor -> x509CertificateExtractor.extract(request))
            .filter(Objects::nonNull)
            .findFirst()
            .orElse(null);
    }
}

==> vitamui-package-9.0.0-MVN_REPO.tar.gz: fr/gouv/vitamui/iam/security/filter/RequestHeadersAuthenticationFilter.java <==
/**
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2019-2020)
 * and the signatories of the "VITAM - Accord du Contributeur" agreement.
 *
 * contact@programmevitam.fr
 *
 * This software is a computer program whose purpose is to implement
 * implement a digital archiving front-office system for the secure and
 * efficient high volumetry VITAM solution.
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
package fr.gouv.vitamui.iam.security.filter;

import fr.gouv.vitamui.commons.rest.client.HttpContext;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.web.authentication.preauth.x509.X509AuthenticationFilter;

import java.util.List;
import java.util.Objects;

/**
 * The authentication filter based on the request headers.
 */
public class RequestHeadersAuthenticationFilter extends X509AuthenticationFilter {

    private final List<X509CertificateExtractor> x509CertificateExtractors;

    private final List<TokenExtractor> tokenExtractors;

    /**
     *
     * @param authenticationManager
     * @param x509CertificateExtractors
     * @param tokenExtractors
     */
    public RequestHeadersAuthenticationFilter(
        final AuthenticationManager authenticationManager,
        final List<X509CertificateExtractor> x509CertificateExtractors,
        List<TokenExtractor> tokenExtractors
    ) {
        super();
        setAuthenticationManager(authenticationManager);
        this.x509CertificateExtractors = x509CertificateExtractors;
        this.tokenExtractors = tokenExtractors;
    }

    /**
     * Return as principal the External Http Context that is built from the request
     */
    @Override
    protected Object getPreAuthenticatedPrincipal(final HttpServletRequest request) {
        logger.debug("request: " + request.getRequestURI() + " - " + request.getQueryString());
        return HttpContext.buildFromExternalRequest(request, extractToken(request));
    }

    private String extractToken(HttpServletRequest request) {
        return tokenExtractors
            .stream()
            .map(tokenExtractor -> tokenExtractor.extract(request))
            .filter(Objects::nonNull)
            .findFirst()
            .orElse(null);
    }

    /**
     * Return as credentials the certificate extracted from the request
     */
    @Override
    protected Object getPreAuthenticatedCredentials(final HttpServletRequest request) {
        // This is a temporary patch to allow both mTLS authentication behind gateway or full mTLS during migration
        return x509CertificateExtractors
            .stream()
            .map(x509CertificateExtractor -> x509CertificateExtractor.extract(request))
            .filter(Objects::nonNull)
            .findFirst()
            .orElse(null);
    }
}
